@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2016 NVIDIA Corporation
+    Copyright (c) 2016-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -277,7 +277,7 @@ static const char *uvm_mem_physical_source(uvm_mem_t *mem)
         return "CPU";
 }
 
-NV_STATUS uvm_mem_map_kernel(uvm_mem_t *mem, const uvm_processor_mask_t *mask)
+NV_STATUS uvm_mem_map_kernel(uvm_mem_t *mem, const uvm_global_processor_mask_t *mask)
 {
     uvm_gpu_t *gpu;
     NV_STATUS status;
@@ -287,13 +287,13 @@ NV_STATUS uvm_mem_map_kernel(uvm_mem_t *mem, const uvm_processor_mask_t *mask)
     if (!mask)
         return NV_OK;
 
-    if (uvm_processor_mask_test(mask, UVM_CPU_ID)) {
+    if (uvm_global_processor_mask_test(mask, UVM_GLOBAL_ID_CPU)) {
         status = uvm_mem_map_cpu(mem, NULL);
         if (status != NV_OK)
             return status;
     }
 
-    for_each_gpu_in_mask(gpu, mask) {
+    for_each_global_gpu_in_mask(gpu, mask) {
         status = uvm_mem_map_gpu_kernel(mem, gpu);
         if (status != NV_OK)
             return status;
@@ -559,7 +559,7 @@ NV_STATUS uvm_mem_map_cpu(uvm_mem_t *mem, struct vm_area_struct *vma)
 
     UVM_ASSERT(mem);
 
-    if (uvm_processor_mask_test(&mem->mapped_on, UVM_CPU_ID)) {
+    if (uvm_global_processor_mask_test(&mem->mapped_on, UVM_GLOBAL_ID_CPU)) {
         // Already mapped
         return NV_OK;
     }
@@ -574,7 +574,7 @@ NV_STATUS uvm_mem_map_cpu(uvm_mem_t *mem, struct vm_area_struct *vma)
     if (status != NV_OK)
         return status;
 
-    uvm_processor_mask_set(&mem->mapped_on, UVM_CPU_ID);
+    uvm_global_processor_mask_set(&mem->mapped_on, UVM_GLOBAL_ID_CPU);
     return NV_OK;
 }
 
@@ -582,7 +582,7 @@ void uvm_mem_unmap_cpu(uvm_mem_t *mem)
 {
     UVM_ASSERT(mem);
 
-    if (!uvm_processor_mask_test(&mem->mapped_on, UVM_CPU_ID)) {
+    if (!uvm_global_processor_mask_test(&mem->mapped_on, UVM_GLOBAL_ID_CPU)) {
         // Already unmapped
         return;
     }
@@ -592,12 +592,12 @@ void uvm_mem_unmap_cpu(uvm_mem_t *mem)
     else
         uvm_mem_unmap_cpu_kernel(mem);
 
-    uvm_processor_mask_clear(&mem->mapped_on, UVM_CPU_ID);
+    uvm_global_processor_mask_clear(&mem->mapped_on, UVM_GLOBAL_ID_CPU);
 }
 
 static void unmap_gpu_sysmem_iommu(uvm_mem_t *mem, uvm_gpu_t *gpu)
 {
-    NvU64 *dma_addrs = mem->sysmem.dma_addrs[uvm_gpu_index(gpu->id)];
+    NvU64 *dma_addrs = mem->sysmem.dma_addrs[uvm_global_id_gpu_index(gpu->global_id)];
     NvU32 i;
 
     UVM_ASSERT(uvm_mem_is_sysmem(mem));
@@ -614,7 +614,7 @@ static void unmap_gpu_sysmem_iommu(uvm_mem_t *mem, uvm_gpu_t *gpu)
     }
 
     uvm_kvfree(dma_addrs);
-    mem->sysmem.dma_addrs[uvm_gpu_index(gpu->id)] = NULL;
+    mem->sysmem.dma_addrs[uvm_global_id_gpu_index(gpu->global_id)] = NULL;
 }
 
 static NV_STATUS map_gpu_sysmem_iommu(uvm_mem_t *mem, uvm_gpu_t *gpu)
@@ -629,7 +629,7 @@ static NV_STATUS map_gpu_sysmem_iommu(uvm_mem_t *mem, uvm_gpu_t *gpu)
     if (!dma_addrs)
         return NV_ERR_NO_MEMORY;
 
-    mem->sysmem.dma_addrs[uvm_gpu_index(gpu->id)] = dma_addrs;
+    mem->sysmem.dma_addrs[uvm_global_id_gpu_index(gpu->global_id)] = dma_addrs;
 
     for (i = 0; i < mem->chunks_count; ++i) {
         status = uvm_gpu_map_cpu_pages(gpu, mem->sysmem.pages[i], mem->chunk_size, &dma_addrs[i]);
@@ -664,11 +664,11 @@ static uvm_gpu_phys_address_t uvm_mem_gpu_physical_vidmem(uvm_mem_t *mem, size_t
 
 static uvm_gpu_phys_address_t uvm_mem_gpu_physical_sysmem(uvm_mem_t *mem, uvm_gpu_t *gpu, size_t offset)
 {
-    NvU64 *dma_addrs = mem->sysmem.dma_addrs[uvm_gpu_index(gpu->id)];
+    NvU64 *dma_addrs = mem->sysmem.dma_addrs[uvm_global_id_gpu_index(gpu->global_id)];
     NvU64 dma_addr = dma_addrs[offset / mem->chunk_size];
 
     UVM_ASSERT(uvm_mem_is_sysmem(mem));
-    UVM_ASSERT(uvm_processor_mask_test(&mem->mapped_phys_on, gpu->id));
+    UVM_ASSERT(uvm_global_processor_mask_test(&mem->mapped_phys_on, gpu->global_id));
 
     return uvm_gpu_phys_address(UVM_APERTURE_SYS, dma_addr + offset % mem->chunk_size);
 }
@@ -728,18 +728,18 @@ static NvU64 uvm_mem_pte_maker(uvm_page_table_range_vec_t *range_vec, NvU64 offs
 static void unmap_gpu(uvm_mem_t *mem, uvm_gpu_t *gpu)
 {
     NV_STATUS status;
-    uvm_page_table_range_vec_t *range_vec = mem->range_vecs[uvm_gpu_index(gpu->id)];
+    uvm_page_table_range_vec_t **range_vec = &mem->range_vecs[uvm_global_id_gpu_index(gpu->global_id)];
     uvm_membar_t tlb_membar = UVM_MEMBAR_SYS;
 
     if (uvm_mem_is_local_vidmem(mem, gpu))
         tlb_membar = UVM_MEMBAR_GPU;
 
-    status = uvm_page_table_range_vec_clear_ptes(range_vec, tlb_membar);
+    status = uvm_page_table_range_vec_clear_ptes(*range_vec, tlb_membar);
     if (status != NV_OK)
         UVM_ERR_PRINT("Clearing PTEs failed: %s, GPU %s\n", nvstatusToString(status), gpu->name);
 
-    uvm_page_table_range_vec_destroy(range_vec);
-    mem->range_vecs[uvm_gpu_index(gpu->id)] = NULL;
+    uvm_page_table_range_vec_destroy(*range_vec);
+    *range_vec = NULL;
 }
 
 static NV_STATUS map_gpu(uvm_mem_t *mem,
@@ -749,7 +749,7 @@ static NV_STATUS map_gpu(uvm_mem_t *mem,
                          const uvm_mem_gpu_mapping_attrs_t *attrs)
 {
     NV_STATUS status;
-    uvm_page_table_range_vec_t **range_vec = &mem->range_vecs[uvm_gpu_index(gpu->id)];
+    uvm_page_table_range_vec_t **range_vec = &mem->range_vecs[uvm_global_id_gpu_index(gpu->global_id)];
     NvU32 page_size;
     uvm_mem_pte_maker_data_t pte_maker_data = {
             .mem = mem,
@@ -794,7 +794,7 @@ NV_STATUS uvm_mem_map_gpu_kernel(uvm_mem_t *mem, uvm_gpu_t *gpu)
 
     UVM_ASSERT(!mem->is_user_allocation);
 
-    if (uvm_processor_mask_test(&mem->mapped_on, gpu->id))
+    if (uvm_global_processor_mask_test(&mem->mapped_on, gpu->global_id))
         return NV_OK;
 
     status = uvm_mem_map_gpu_phys(mem, gpu);
@@ -806,7 +806,7 @@ NV_STATUS uvm_mem_map_gpu_kernel(uvm_mem_t *mem, uvm_gpu_t *gpu)
     if (status != NV_OK)
         return status;
 
-    uvm_processor_mask_set(&mem->mapped_on, gpu->id);
+    uvm_global_processor_mask_set(&mem->mapped_on, gpu->global_id);
 
     return NV_OK;
 }
@@ -818,7 +818,7 @@ NV_STATUS uvm_mem_map_gpu_user(uvm_mem_t *mem, uvm_gpu_t *gpu, const uvm_mem_gpu
 
     UVM_ASSERT(mem->is_user_allocation);
 
-    if (uvm_processor_mask_test(&mem->mapped_on, gpu->id))
+    if (uvm_global_processor_mask_test(&mem->mapped_on, gpu->global_id))
         return NV_OK;
 
     status = uvm_mem_map_gpu_phys(mem, gpu);
@@ -831,7 +831,7 @@ NV_STATUS uvm_mem_map_gpu_user(uvm_mem_t *mem, uvm_gpu_t *gpu, const uvm_mem_gpu
     if (status != NV_OK)
         return status;
 
-    uvm_processor_mask_set(&mem->mapped_on, gpu->id);
+    uvm_global_processor_mask_set(&mem->mapped_on, gpu->global_id);
 
     return NV_OK;
 }
@@ -841,13 +841,13 @@ void uvm_mem_unmap_gpu(uvm_mem_t *mem, uvm_gpu_t *gpu)
     UVM_ASSERT(mem);
     UVM_ASSERT(gpu);
 
-    if (!uvm_processor_mask_test(&mem->mapped_on, gpu->id)) {
+    if (!uvm_global_processor_mask_test(&mem->mapped_on, gpu->global_id)) {
         // Already unmapped
         return;
     }
 
     unmap_gpu(mem, gpu);
-    uvm_processor_mask_clear(&mem->mapped_on, gpu->id);
+    uvm_global_processor_mask_clear(&mem->mapped_on, gpu->global_id);
 }
 
 NV_STATUS uvm_mem_map_gpu_phys(uvm_mem_t *mem, uvm_gpu_t *gpu)
@@ -857,7 +857,7 @@ NV_STATUS uvm_mem_map_gpu_phys(uvm_mem_t *mem, uvm_gpu_t *gpu)
     if (!uvm_mem_is_sysmem(mem))
         return NV_OK;
 
-    if (uvm_processor_mask_test(&mem->mapped_phys_on, gpu->id)) {
+    if (uvm_global_processor_mask_test(&mem->mapped_phys_on, gpu->global_id)) {
         // Already mapped
         return NV_OK;
     }
@@ -866,7 +866,7 @@ NV_STATUS uvm_mem_map_gpu_phys(uvm_mem_t *mem, uvm_gpu_t *gpu)
     if (status != NV_OK)
         return status;
 
-    uvm_processor_mask_set(&mem->mapped_phys_on, gpu->id);
+    uvm_global_processor_mask_set(&mem->mapped_phys_on, gpu->global_id);
 
     return NV_OK;
 }
@@ -881,13 +881,13 @@ void uvm_mem_unmap_gpu_phys(uvm_mem_t *mem, uvm_gpu_t *gpu)
 
     uvm_mem_unmap_gpu(mem, gpu);
 
-    if (!uvm_processor_mask_test(&mem->mapped_phys_on, gpu->id)) {
+    if (!uvm_global_processor_mask_test(&mem->mapped_phys_on, gpu->global_id)) {
         // Already unmapped
         return;
     }
 
     unmap_gpu_sysmem_iommu(mem, gpu);
-    uvm_processor_mask_clear(&mem->mapped_phys_on, gpu->id);
+    uvm_global_processor_mask_clear(&mem->mapped_phys_on, gpu->global_id);
 }
 
 void uvm_mem_free(uvm_mem_t *mem)
@@ -897,13 +897,12 @@ void uvm_mem_free(uvm_mem_t *mem)
     if (mem == NULL)
         return;
 
-    if (uvm_processor_mask_test(&mem->mapped_on, UVM_CPU_ID))
-        uvm_mem_unmap_cpu(mem);
+    uvm_mem_unmap_cpu(mem);
 
-    for_each_gpu_in_mask(gpu, &mem->mapped_on)
+    for_each_global_gpu_in_mask(gpu, &mem->mapped_on)
         uvm_mem_unmap_gpu(mem, gpu);
 
-    for_each_gpu_in_mask(gpu, &mem->mapped_phys_on)
+    for_each_global_gpu_in_mask(gpu, &mem->mapped_phys_on)
         uvm_mem_unmap_gpu_phys(mem, gpu);
 
     if (!mem->is_user_allocation && mem->kernel.range_alloc.node)
@@ -917,7 +916,7 @@ void uvm_mem_free(uvm_mem_t *mem)
 void *uvm_mem_get_cpu_addr_kernel(uvm_mem_t *mem)
 {
     UVM_ASSERT(!mem->is_user_allocation);
-    UVM_ASSERT(uvm_processor_mask_test(&mem->mapped_on, UVM_CPU_ID));
+    UVM_ASSERT(uvm_global_processor_mask_test(&mem->mapped_on, UVM_GLOBAL_ID_CPU));
 
     return mem->kernel.cpu_addr;
 }
@@ -925,7 +924,7 @@ void *uvm_mem_get_cpu_addr_kernel(uvm_mem_t *mem)
 NvU64 uvm_mem_get_gpu_va_kernel(uvm_mem_t *mem, uvm_gpu_t *gpu)
 {
     UVM_ASSERT(!mem->is_user_allocation);
-    UVM_ASSERT_MSG(uvm_processor_mask_test(&mem->mapped_on, gpu->id), "GPU %s\n", gpu->name);
+    UVM_ASSERT_MSG(uvm_global_processor_mask_test(&mem->mapped_on, gpu->global_id), "GPU %s\n", gpu->name);
 
     return reserved_gpu_va(mem, gpu);
 }
